"""
API响应配置文件
包含API响应格式、状态码和消息模板等配置
"""
from typing import Dict, Any, Optional, Type

class ApiResponseModel:
    """API响应模型配置"""
    CODE = int  # 响应状态码
    MESSAGE = str  # 响应消息
    DATA = None  # 响应数据，可为任意类型

class ApiResponseCode:
    """API响应状态码"""
    SUCCESS = 200  # 成功
    BAD_REQUEST = 400  # 请求错误
    UNAUTHORIZED = 401  # 未授权
    FORBIDDEN = 403  # 禁止访问
    NOT_FOUND = 404  # 资源不存在
    SERVER_ERROR = 500  # 服务器错误

class ApiResponseMessage:
    """API响应消息模板"""
    # 通用消息
    SUCCESS = "操作成功"
    FAILED = "操作失败"
    SERVER_ERROR = "服务器内部错误"
    
    # 任务相关消息
    class Task:
        """任务相关消息"""
        CREATED = "任务创建成功"
        UPDATED = "任务更新成功"
        DELETED = "任务删除成功"
        EXECUTED = "任务执行成功"
        CANCELED = "任务取消成功"
        NOT_FOUND = "任务不存在"
    
    # 工作流相关消息
    class Workflow:
        """工作流相关消息"""
        SAVED = "工作流保存成功"
        VALIDATED = "工作流验证成功"
        NOT_FOUND = "工作流不存在"
        CREATED = "工作流创建成功"
        UPDATED = "工作流更新成功"
        DELETED = "工作流删除成功"
        EXECUTED = "工作流执行成功"
        IMPORTED = "工作流导入成功"
        EXPORTED = "工作流导出成功"
    
    # 组件相关消息
    class Component:
        """组件相关消息"""
        FETCHED = "获取组件类型成功"
        DISCOVERED = "自动发现并注册组件成功"

class ApiPagination:
    """分页配置"""
    DEFAULT_PAGE = 1  # 默认页码
    DEFAULT_PAGE_SIZE = 10  # 默认每页记录数
    MAX_PAGE_SIZE = 100  # 最大每页记录数 